@@ -39,6 +39,14 @@
 #include <sys/socket.h>
 #endif
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#ifdef HAVE_NETINET_IN_H
+#include <netinet/in.h>
+#endif
+
 #include <openssl/ssl.h>
 
 #include "utilities.h"
