@@ -54,12 +54,12 @@
 #define MANAGEMENT_CONFIG_KEYWORD_CONTROL_PORT		2
 #define MANAGEMENT_CONFIG_KEYWORD_AUTHORIZED_HOST	3
 #define MANAGEMENT_CONFIG_KEYWORD_NOTIFY_EMAIL      4
-#define MANAGEMENT_CONFIG_KEYWORD_ADMIN_EMAIL       5
-#define MANAGEMENT_CONFIG_KEYWORD_NOTIFY_SMTP_HOST  6
-#define MANAGEMENT_CONFIG_KEYWORD_NOTIFY_SMTP_PORT  7
-#define MANAGEMENT_CONFIG_KEYWORD_HTTP_PORT         8
-#define MANAGEMENT_CONFIG_KEYWORD_HTTP_HOST         9
-#define MANAGEMENT_CONFIG_KEYWORD_HOSTS_DIRECTORY   10
+#define MANAGEMENT_CONFIG_KEYWORD_NOTIFY_SMTP_HOST  5
+#define MANAGEMENT_CONFIG_KEYWORD_NOTIFY_SMTP_PORT  6
+#define MANAGEMENT_CONFIG_KEYWORD_HTTP_PORT         7
+#define MANAGEMENT_CONFIG_KEYWORD_HTTP_HOST         8
+#define MANAGEMENT_CONFIG_KEYWORD_HOSTS_DIRECTORY   9
+#define MANAGEMENT_CONFIG_KEYWORD_NOTIFY_APP        10
 
 #define MAX_MANAGEMENT_CONFIG_LINE_LENGTH	        512
 #define MAX_MANAGEMENT_CONFIG_KEY_LENGTH	        256
@@ -90,10 +90,9 @@ typedef struct management_config
     int http_port;
 
     char http_host[MAX_HTTP_HOST_LENGTH];
-
     char notify_email[MAX_NOTIFY_EMAIL_LENGTH];
-    char admin_email[MAX_NOTIFY_EMAIL_LENGTH];
     char notify_smtp_host[MAX_NOTIFY_SMTP_HOST_LENGTH];
+    char notify_app[MAX_PATH_LENGTH];
     unsigned int notify_smtp_port;
 
     char hosts_directory[MAX_PATH_LENGTH];
