@@ -42,30 +42,28 @@
 #include "md_utilities.h"
 #include "md_notify.h"
 
-#ifdef HAVE_SYS_WAIT_H
-#include <sys/wait.h>
-#endif
-
 #include "logging.h"
-#include <signal.h>
 
 extern char root_path[MAX_PATH_LENGTH];
 extern int schedule_pipe[2];
 extern OSI_MANAGEMENT_CONFIG *config;
 
 extern void parse_configuration_file();
+extern void check_for_signals();
+
+#ifndef WIN32
+extern pid_t scheduler_pid;
+#endif
 
-static volatile osi_atomic_t received_sigchld = 0;
-static volatile osi_atomic_t received_sigint = 0;
-static volatile osi_atomic_t received_sigterm = 0;
-static volatile osi_atomic_t received_sigkill = 0;
-static volatile osi_atomic_t received_sigpipe = 0;
 
 
 THREAD_FUNCTION_TYPE md_scheduler_run( void *unused )
 {
     osi_list schedules = md_schedules_read();
-    initialize_scheduling_signals();
+
+#ifndef WIN32
+    scheduler_pid = getpid();
+#endif
 
     while( 1 )
     {
@@ -227,9 +225,12 @@ exit_gracefully:
 
                 if( schedule_failed )
                 {
+                    MD_NOTIFY_CTX ctx;
                     char *email = config->notify_email;
                     host_brief = osi_read_host_brief( s->host );
 
+                    memset( &ctx, 0, sizeof(ctx) );
+
                     if( host_brief && strlen( host_brief->notify_email ) )
                     {
                         email = host_brief->notify_email;
@@ -239,21 +240,11 @@ exit_gracefully:
                         ( host_brief->notify_enabled &&
                         (host_brief->notify_flags & OSI_NOTIFY_SCAN_FAILED) ) )
                     {
-
-                        md_notify_scan_failed( s->host,
-                                               email,
-                                               current_seconds,
-                                               failure_message );
-                    }
-
-                    /* always notify admin email. */
-
-                    if ( strlen( config->admin_email ) > 0 )
-                    {
-                        md_notify_scan_failed( s->host,
-                                               config->admin_email,
-                                               current_seconds,
-                                               failure_message );
+                        md_notify_init( &ctx, NOTIFY_TYPE_SCHEDULE_FAIL );
+                        ctx.host = s->host;
+                        ctx.message = failure_message;
+                        ctx.email = email;
+                        md_notify( &ctx );
                     }
 
                     if( host_brief )
@@ -308,126 +299,6 @@ osi_list md_schedules_read()
     return schedules;
 }
 
-/******************************************************************************
-**
-**    Function: initialize_scheduling_signals
-**
-**    Purpose:  add various common signals to the signal handler.
-**
-******************************************************************************/
-
-void initialize_scheduling_signals()
-{
-#ifdef HAVE_SIGSET
-
-    sigset( SIGINT, scheduling_signal_handler );
-    sigset( SIGTERM, scheduling_signal_handler );
-    sigset( SIGCHLD, scheduling_signal_handler );
-    sigset( SIGPIPE, scheduling_signal_handler );
-    sigset( SIGKILL, scheduling_signal_handler );
-
-#else
-
-    signal( SIGINT, scheduling_signal_handler );
-    signal( SIGTERM, scheduling_signal_handler );
-
-    /* windows doesn't know about these. */
-
-#ifndef WIN32
-    signal( SIGCHLD, scheduling_signal_handler );
-    signal( SIGKILL, scheduling_signal_handler );
-    signal( SIGPIPE, scheduling_signal_handler );
-#endif
-
-#endif /* HAVE_SIGSET */
-
-}
-
-/****************************************************************************
-**
-**    Function: signal_handler
-**
-**    Purpose:  handle common signals, this is mostly for unix clients.
-**
-******************************************************************************/
-
-void scheduling_signal_handler( int signal )
-{
-    switch( signal )
-    {
-        case SIGINT:
-            received_sigint = 1;
-            break;
-
-        case SIGTERM:
-            received_sigterm = 1;
-            break;
-
-#ifndef WIN32
-
-        case SIGKILL:
-            received_sigkill = 1;
-            break;
-
-        case SIGCHLD:
-            received_sigchld = 1;
-            break;
-        
-        case SIGPIPE:
-            received_sigpipe = 1;
-            break;
-#endif
-        default:
-            break;
-    }
-}
-
-static void check_for_signals()
-{
-    int status = 0;
-    pid_t pid;
-
-    if( received_sigint )
-    {
-        log_warning( LOG_ID_SCHEDULER_INFO, NULL, "received SIGINT" );
-        exit(-1);
-    }
-
-    if( received_sigterm )
-    {
-        log_warning( LOG_ID_SCHEDULER_INFO, NULL, "received SIGTERM" );
-        exit(-1);
-    }
-
-    if( received_sigkill )
-    {
-        log_warning( LOG_ID_SCHEDULER_INFO, NULL, "received SIGKILL" );
-        exit(-1);
-    }
-
-#ifndef WIN32
-
-    if( received_sigchld )
-    {
-        received_sigchld = 0;
-
-        while( ( pid = waitpid( -1, &status, WNOHANG ) ) > 0 ||
-               ( ( pid < 0 ) && ( errno == EINTR ) ) )
-        ;
-
-        log_info( LOG_ID_SCHEDULER_INFO, NULL, "scheduler child terminated." );
-    }
-
-#endif
-
-    if( received_sigpipe )
-    {
-        received_sigpipe = 0;
-        log_warning( LOG_ID_SCHEDULER_INFO, NULL, "received SIGPIPE" );
-    }
-}
-
-
 void md_schedules_signal_updated()
 {
     osi_write( schedule_pipe[1], "x", 1 );
